@@ -7,7 +7,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2015 jointly by the following organizations:
+ * Copyright (C) 2013-2016 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -1638,8 +1638,8 @@ protected:
   virtual void writeXMLNS (XMLOutputStream& stream) const;
 
 
-  int mLevel;
-  int mVersion;
+  unsigned int mLevel;
+  unsigned int mVersion;
 
   Model* mModel;
   std::string mLocationURI;
