@@ -7,7 +7,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2015 jointly by the following organizations:
+ * Copyright (C) 2013-2016 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -202,7 +202,7 @@ SBO::isChildOf(unsigned int term, unsigned int parent)
   {
     populateSBOTree();
   }
-  ParentRange range  = mParent.equal_range(term);
+  ParentRange range  = mParent.equal_range((int)term);
   deque<unsigned int>  nodes;
 
 
@@ -223,7 +223,7 @@ SBO::isChildOf(unsigned int term, unsigned int parent)
     }
 
     // Copy parents of p to nodes and continue search.
-    range = mParent.equal_range(p);
+    range = mParent.equal_range((int)p);
     transform(range.first, range.second, back_inserter(nodes), GetSecond());
   }
 
