@@ -7,7 +7,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2015 jointly by the following organizations:
+ * Copyright (C) 2013-2016 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -879,10 +879,8 @@ ASTNode::getReal () const
     case AST_CONSTANT_TRUE:
     case AST_CONSTANT_FALSE:
       return 0;
-      break;
     default:
       return mNumber->getValue();
-      break;
     }
   }
   else
@@ -1312,7 +1310,7 @@ ASTNode::setType (int type)
     {
       if (found == false)
       {
-        const char * name = ASTBase::getPlugin(i)->getNameFromType(type);
+        const char * name1 = ASTBase::getPlugin(i)->getNameFromType(type);
         if (representsFunction(type, ASTBase::getPlugin(i)) == true)
         {
           mFunction = new ASTFunction (type);
@@ -1329,7 +1327,7 @@ ASTNode::setType (int type)
           found = true;
         }
         else if (ASTBase::getPlugin(i)
-                          ->isTopLevelMathMLFunctionNodeTag(name) == true)
+                          ->isTopLevelMathMLFunctionNodeTag(name1) == true)
         {
           mFunction = new ASTFunction (type);
           if (copyNumber != NULL)
@@ -2692,6 +2690,11 @@ ASTNode::swapChildren(ASTNode* that)
 void 
 ASTNode::write(XMLOutputStream& stream) const
 {
+  /* writing the opening math and ns has moved to the MathML writing code
+   * as trying to keep track of a child node could cause issues
+   * when manipulating or using child ASTs
+   */
+#if (0)
   if (ASTBase::isChild() == false)
   {
     static const string uri = "http://www.w3.org/1998/Math/MathML";
@@ -2716,11 +2719,8 @@ ASTNode::write(XMLOutputStream& stream) const
       ASTBase::getPlugin(i)->writeXMLNS(stream);
     }
   }
+#endif
 
-  //if (getSemanticsFlag() == true)
-  //{
-  //  stream.startElement("semantics");
-  //}
   if (mNumber != NULL)
   {
     mNumber->write(stream);
@@ -2731,20 +2731,16 @@ ASTNode::write(XMLOutputStream& stream) const
     mFunction->write(stream);
   }
 
-  //if (getSemanticsFlag() == true)
-  //{
-  //  for (unsigned int n = 0; n < getNumSemanticsAnnotations(); n++)
-  //  {
-  //    stream << *(getSemanticsAnnotation(n));
-  //  }
-  //  stream.endElement("semantics");
-  //}
-
+  /* writing the closing math has moved to the MathML writing code
+   * as trying to keep track of a child node could cause issues
+   * when manipulating or using child ASTs
+   */
+#if (0)
   if (ASTBase::isChild() == false)
   {
     stream.endElement("math");
   }
-
+#endif
 }
 /** @endcond */
 
@@ -3009,6 +3005,10 @@ ASTNode::renameSIdRefs(const std::string& oldid, const std::string& newid)
   {
     getChild(child)->renameSIdRefs(oldid, newid);
   }
+
+  for (unsigned int p=0; p<getNumPlugins(); p++) {
+    getPlugin(p)->renameSIdRefs(oldid, newid);
+  }
 }
 
 
@@ -3027,6 +3027,10 @@ ASTNode::renameUnitSIdRefs(const std::string& oldid, const std::string& newid)
   {
     getChild(child)->renameUnitSIdRefs(oldid, newid);
   }
+
+  for (unsigned int p=0; p<getNumPlugins(); p++) {
+    getPlugin(p)->renameUnitSIdRefs(oldid, newid);
+  }
 }
 
 
@@ -3047,6 +3051,10 @@ ASTNode::replaceIDWithFunction(const std::string& id, const ASTNode* function)
       child->replaceIDWithFunction(id, function);
     }
   }
+
+  for (unsigned int p=0; p<getNumPlugins(); p++) {
+    getPlugin(p)->replaceIDWithFunction(id, function);
+  }
 }
 /** @endcond */
 
@@ -3218,7 +3226,7 @@ ASTNode::getNumVariablesWithUndeclaredUnits(Model * m) const
     // loop thru the list and check the unit status of each variable
     for (unsigned int v = 0; v < variables->size(); v++)
     {
-      string id = variables->at(v);
+      string id = variables->at((int)v);
       
 
       if (m->getParameter(id) != NULL)
@@ -4632,7 +4640,7 @@ ASTNode_setDefinitionURLString(ASTNode_t* node, const char * defnURL)
  */
 LIBSBML_EXTERN
 int
-ASTNode_true(const ASTNode *node)
+ASTNode_true(const ASTNode *)
 {
   return 1;
 }
