@@ -8,7 +8,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2015 jointly by the following organizations:
+ * Copyright (C) 2013-2016 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -926,7 +926,7 @@ ArraysASTPlugin::getNameFromType(int type) const
 {
 
   static const int size = sizeof(ARRAYS_MATHML_ELEMENTS) / sizeof(ARRAYS_MATHML_ELEMENTS[0]);
-  if (type >= AST_QUALIFIER_CONDITION && type < AST_ARRAYS_UNKNOWN)
+  if (type >= AST_LINEAR_ALGEBRA_SELECTOR && type < AST_ARRAYS_UNKNOWN)
   {
     bool found = false;
     unsigned int i;
@@ -1105,6 +1105,9 @@ ArraysASTPlugin::isPackageInfixFunction() const
   case AST_LINEAR_ALGEBRA_SELECTOR:
   case AST_LINEAR_ALGEBRA_VECTOR_CONSTRUCTOR:
     return false;
+  case AST_ARRAYS_UNKNOWN:
+  default:
+    return false;
 #if (0)
   case AST_LINEAR_ALGEBRA_MATRIX_CONSTRUCTOR:
     //An empty matrix or a matrix with only one row looks like a vector, so we have to use the functional form
