@@ -9,7 +9,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2015 jointly by the following organizations:
+ * Copyright (C) 2013-2016 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -64,7 +64,7 @@ ExtModelReferenceCycles::~ExtModelReferenceCycles ()
  * event assignments and assignment rules.
  */
 void
-ExtModelReferenceCycles::check_ (const Model& m, const Model& object)
+ExtModelReferenceCycles::check_ (const Model& m, const Model&)
 {
   mIdMap.clear();
 
@@ -138,7 +138,7 @@ ExtModelReferenceCycles::addAllReferences(const SBMLDocument* doc,
 void 
 ExtModelReferenceCycles::addModelReferences(const std::string &location, 
                           const CompSBMLDocumentPlugin* docPlug,
-                          const CompModelPlugin* modelPlug)
+                          const CompModelPlugin*)
 {
   for (unsigned int i = 0; i < docPlug->getNumExternalModelDefinitions(); i++)
   {
@@ -227,7 +227,7 @@ ExtModelReferenceCycles::determineCycles(const Model& m)
    
   for (unsigned int n = 0; n < variables.size(); n++)
   {
-    id = variables.at(n);
+    id = variables.at((int)n);
     range = mIdMap.equal_range(id);
     for (it = range.first; it != range.second; it++)
     {
