@@ -9,7 +9,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2015 jointly by the following organizations:
+ * Copyright (C) 2013-2016 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -48,7 +48,7 @@ LIBSBML_CPP_NAMESPACE_BEGIN
  * Creates a new FbcModelPlugin
  */
 FbcModelPlugin::FbcModelPlugin(const std::string& uri,  
-                                 const std::string& prefix, 
+                               const std::string& prefix, 
                                FbcPkgNamespaces* fbcns) :
     SBasePlugin(uri, prefix, fbcns)
   , mStrict (false)
@@ -173,6 +173,7 @@ FbcModelPlugin::appendFrom(const Model* model)
 //
 //---------------------------------------------------------------
 
+/** @cond doxygenLibsbmlInternal */
 /*
  * create object
  */
@@ -182,10 +183,10 @@ FbcModelPlugin::createObject (XMLInputStream& stream)
   SBase* object = NULL; 
 
   const std::string&      name   = stream.peek().getName(); 
-  const XMLNamespaces&    xmlns  = stream.peek().getNamespaces(); 
+  const XMLNamespaces&    xmlns1  = stream.peek().getNamespaces();
   const std::string&      prefix = stream.peek().getPrefix(); 
 
-  const std::string& targetPrefix = (xmlns.hasURI(mURI)) ? xmlns.getPrefix(mURI) : mPrefix;
+  const std::string& targetPrefix = (xmlns1.hasURI(mURI)) ? xmlns1.getPrefix(mURI) : mPrefix;
 
   if (prefix == targetPrefix) 
   { 
@@ -256,8 +257,9 @@ FbcModelPlugin::createObject (XMLInputStream& stream)
 
   return object; 
 }
+/** @endcond */
 
-
+/** @cond doxygenLibsbmlInternal */
 /*
  * write elements
  */
@@ -279,6 +281,7 @@ FbcModelPlugin::writeElements (XMLOutputStream& stream) const
     mGeneProducts.write(stream);
   } 
 }
+/** @endcond */
 
 LIBSBML_EXTERN
 void
@@ -562,20 +565,20 @@ FbcModelPlugin::readAttributes (const XMLAttributes& attributes,
   if (getErrorLog() != NULL)
   {
     numErrs = getErrorLog()->getNumErrors();
-    for (int n = numErrs-1; n >= 0; n--)
+    for (int n = (int)numErrs-1; n >= 0; n--)
     {
-      if (getErrorLog()->getError(n)->getErrorId() == UnknownPackageAttribute)
+      if (getErrorLog()->getError((unsigned int)n)->getErrorId() == UnknownPackageAttribute)
       {
         const std::string details =
-                          getErrorLog()->getError(n)->getMessage();
+                          getErrorLog()->getError((unsigned int)n)->getMessage();
         getErrorLog()->remove(UnknownPackageAttribute);
         getErrorLog()->logPackageError("fbc", FbcUnknown,
                        getPackageVersion(), sbmlLevel, sbmlVersion, details, getLine(), getColumn());
       }
-      else if (getErrorLog()->getError(n)->getErrorId() == UnknownCoreAttribute)
+      else if (getErrorLog()->getError((unsigned int)n)->getErrorId() == UnknownCoreAttribute)
       {
         const std::string details =
-                          getErrorLog()->getError(n)->getMessage();
+                          getErrorLog()->getError((unsigned int)n)->getMessage();
         getErrorLog()->remove(UnknownCoreAttribute);
         getErrorLog()->logPackageError("fbc", FbcUnknown,
                        getPackageVersion(), sbmlLevel, sbmlVersion, details, getLine(), getColumn());
@@ -597,13 +600,13 @@ FbcModelPlugin::readAttributes (const XMLAttributes& attributes,
               getErrorLog()->contains(XMLAttributeTypeMismatch))
       {
         getErrorLog()->remove(XMLAttributeTypeMismatch);
-        getErrorLog()->logPackageError("fbc", FbcNSUndeclared,
+        getErrorLog()->logPackageError("fbc", FbcModelStrictMustBeBoolean,
                      getPackageVersion(), sbmlLevel, sbmlVersion, "", getLine(), getColumn());
       }
       else
       {
         std::string message = "Fbc attribute 'strict' is missing from <Model> object.";
-        getErrorLog()->logPackageError("fbc", FbcNSUndeclared,
+        getErrorLog()->logPackageError("fbc", FbcModelMustHaveStrict,
                        getPackageVersion(), sbmlLevel, sbmlVersion, message, getLine(), getColumn());
       }
     }
@@ -1375,7 +1378,6 @@ ListOfGeneAssociations*
   return &mAssociations;
 }
 
-
 /*
 * Returns the GeneAssociation object that belongs to the given index. If the
 * index is invalid, @c NULL is returned.
@@ -1390,7 +1392,6 @@ const GeneAssociation*
   return static_cast<const GeneAssociation*>(mAssociations.get(n));
 }
 
-
 /*
 * Returns the GeneAssociation object that belongs to the given index. If the
 * index is invalid, @c NULL is returned.
@@ -1405,7 +1406,6 @@ GeneAssociation*
   return static_cast<GeneAssociation*>(mAssociations.get(n));
 }
 
-
 /*
 * Returns the GeneAssociation object based on its identifier.
 *
@@ -1424,7 +1424,6 @@ GeneAssociation*
   return static_cast<GeneAssociation*>(mAssociations.get(sid));
 }
 
-
 /*
 * Returns the GeneAssociation object based on its identifier.
 *
@@ -1485,7 +1484,6 @@ int
   return LIBSBML_OPERATION_SUCCESS;
 }
 
-
 /*
 * Creates a new GeneAssociation object and adds it to the list of GeneAssociation objects
 * and returns it.
@@ -1519,7 +1517,6 @@ GeneAssociation*
   return association;
 }
 
-
 /*
 * Removes the nth GeneAssociation object from this plugin object and
 * returns a pointer to it.
@@ -1539,7 +1536,6 @@ GeneAssociation*
   return static_cast<GeneAssociation*>(mAssociations.remove(n));
 }
 
-
 /*
 * Removes the GeneAssociation object with the given @p id attribute from 
 * this plugin object and returns a pointer to it.
@@ -1559,7 +1555,6 @@ GeneAssociation*
   return static_cast<GeneAssociation*>(mAssociations.remove(sid));
 }
 
-
 /*
 * Returns the number of GeneAssociation object in this plugin object.
 *
@@ -1568,13 +1563,14 @@ GeneAssociation*
 int 
   FbcModelPlugin::getNumGeneAssociations() const
 {
-  return mAssociations.size();
+  return (int)mAssociations.size();
 }
 
 
 //---------------------------------------------------------------
 
 
+/** @cond doxygenLibsbmlInternal */
 /*
  * Sets the parent SBMLDocument of this SBML object.
  *
@@ -1590,6 +1586,8 @@ FbcModelPlugin::setSBMLDocument(SBMLDocument* d)
   mObjectives.setSBMLDocument(d);  
   mGeneProducts.setSBMLDocument(d);
 }
+/** @endcond */
+
 
 /** @cond doxygenLibsbmlInternal */
 void
@@ -1599,6 +1597,7 @@ FbcModelPlugin::connectToChild()
 }
 /** @endcond */
 
+/** @cond doxygenLibsbmlInternal */
 /*
  * Connect to parent.
  */
@@ -1618,8 +1617,10 @@ FbcModelPlugin::connectToParent(SBase* sbase)
     mGeneProducts.connectToParent(sbase);
   }
 }
+/** @endcond */
 
 
+/** @cond doxygenLibsbmlInternal */
 /*
  * Enables the given package.
  */
@@ -1638,8 +1639,9 @@ FbcModelPlugin::enablePackageInternal(const std::string& pkgURI,
     mGeneProducts.enablePackageInternal(pkgURI, pkgPrefix, flag);
   }
 }
+/** @endcond */
 
-
+/** @cond doxygenLibsbmlInternal */
 /*
  * Accept the SBMLVisitor.
  */
@@ -1668,6 +1670,7 @@ FbcModelPlugin::accept(SBMLVisitor& v) const
 
   return true;
 }
+/** @endcond */
 
 
 
