@@ -1,13 +1,13 @@
 /**
- * @file:   FbcAssociation.h
- * @brief:  Implementation of the FbcAssociation class
- * @author: SBMLTeam
+ * @file   FbcAssociation.h
+ * @brief  Implementation of the FbcAssociation class
+ * @author SBMLTeam
  *
  * <!--------------------------------------------------------------------------
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2014 jointly by the following organizations:
+ * Copyright (C) 2013-2016 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -29,9 +29,25 @@
  * in the file named "LICENSE.txt" included with this software distribution
  * and also available online as http://sbml.org/software/libsbml/license.html
  * ------------------------------------------------------------------------ -->
+ *
+ * @class FbcAssociation
+ * @sbmlbrief{fbc} Base class for FbcAnd, FbcOr, and GeneProductRef
+ *
+ * The FbcAssociation class is the abstract base class for the classes that
+ * can be used as children of the GeneProductAssociation child of a Reaction.
+ * The FbcAnd class is used when all of its children are definitely associated
+ * with the Reaction; the FbcOr class is used when at least one of its children
+ * are associated with the Reaction; and the GeneProductRef class is used to
+ * denote a particular GeneProduct.
+ *
+ * @copydetails doc_note_fbcv2_annotation_replacement
+ *
+ * @see ListOfFbcAssociations
+ * @see FbcAnd
+ * @see FbcOr
+ * @see GeneProductRef
  */
 
-
 #ifndef FbcAssociation_H__
 #define FbcAssociation_H__
 
@@ -64,21 +80,24 @@ class LIBSBML_EXTERN FbcAssociation : public SBase
 {
 
 protected:
-
-
-
+  /** @cond doxygenLibsbmlInternal */
   std::string   mElementName;
+  /** @endcond */
 
 public:
 
   /**
-   * Creates a new FbcAssociation with the given level, version, and package version.
+   * Creates a new FbcAssociation with the given SBML Level, Version, and
+   * &ldquo;fbc&rdquo;package version.
    *
-   * @param level an unsigned int, the SBML Level to assign to this FbcAssociation
+   * @param level an unsigned int, the SBML Level to assign to this
+   * FbcAssociation
    *
-   * @param version an unsigned int, the SBML Version to assign to this FbcAssociation
+   * @param version an unsigned int, the SBML Version to assign to this
+   * FbcAssociation
    *
-   * @param pkgVersion an unsigned int, the SBML Fbc Version to assign to this FbcAssociation
+   * @param pkgVersion an unsigned int, the SBML &ldquo;fbc&rdquo; package
+   * Version to assign to this FbcAssociation
    */
   FbcAssociation(unsigned int level      = FbcExtension::getDefaultLevel(),
                  unsigned int version    = FbcExtension::getDefaultVersion(),
@@ -143,17 +162,20 @@ public:
 
 
   /**
-   * Returns @c true, if this abstract "FbcAssociation" is of type GeneProductRef.
+   * Returns @c true, if this abstract "FbcAssociation" is of type
+   * GeneProductRef.
    *
-   * @return @c true, if this abstract "FbcAssociation" is of type GeneProductRef.
+   * @return @c true, if this abstract "FbcAssociation" is of type
+   * GeneProductRef.
    *
    */
   virtual bool isGeneProductRef() const;
 
 
   /**
-   * Returns the XML element name of this object, which for FbcAssociation, is
-   * always @c "fbcAssociation".
+   * Returns the XML element name of this object.
+   *
+   * For FbcAssociation, the XML element name is always @c "fbcAssociation".
    *
    * @return the name of this element, i.e. @c "fbcAssociation".
    */
@@ -162,33 +184,16 @@ public:
 
   /**
    * Returns the libSBML type code for this SBML object.
-   * 
-   * @if clike LibSBML attaches an identifying code to every kind of SBML
-   * object.  These are known as <em>SBML type codes</em>.  The set of
-   * possible type codes is defined in the enumeration #SBMLTypeCode_t.
-   * The names of the type codes all begin with the characters @c
-   * SBML_. @endif@if java LibSBML attaches an identifying code to every
-   * kind of SBML object.  These are known as <em>SBML type codes</em>.  In
-   * other languages, the set of type codes is stored in an enumeration; in
-   * the Java language interface for libSBML, the type codes are defined as
-   * static integer constants in the interface class {@link
-   * libsbmlConstants}.  The names of the type codes all begin with the
-   * characters @c SBML_. @endif@if python LibSBML attaches an identifying
-   * code to every kind of SBML object.  These are known as <em>SBML type
-   * codes</em>.  In the Python language interface for libSBML, the type
-   * codes are defined as static integer constants in the interface class
-   * @link libsbml@endlink.  The names of the type codes all begin with the
-   * characters @c SBML_. @endif@if csharp LibSBML attaches an identifying
-   * code to every kind of SBML object.  These are known as <em>SBML type
-   * codes</em>.  In the C# language interface for libSBML, the type codes
-   * are defined as static integer constants in the interface class @link
-   * libsbmlcs.libsbml@endlink.  The names of the type codes all begin with
-   * the characters @c SBML_. @endif
    *
-   * @return the SBML type code for this object, or
-   * @link SBMLTypeCode_t#SBML_UNKNOWN SBML_UNKNOWN@endlink (default).
+   * @copydetails doc_what_are_typecodes
+   *
+   * @return the SBML type code for this object:
+   * @sbmlconstant{SBML_FBC_ASSOCIATION, SBMLTypeCode_t} (default).
+   *
+   * @copydetails doc_warning_typecodes_not_unique
    *
    * @see getElementName()
+   * @see getPackageName()
    */
   virtual int getTypeCode () const;
 
@@ -197,7 +202,8 @@ public:
    * Predicate returning @c true if all the required attributes
    * for this FbcAssociation object have been set.
    *
-   * @note The required attributes for a FbcAssociation object are:
+   * @note FbcAssociation has no required attributes, so this
+   * method always returns @c true.
    *
    * @return a boolean value indicating whether all the required
    * attributes for this object have been defined.
@@ -214,7 +220,6 @@ public:
    */
   virtual void writeElements (XMLOutputStream& stream) const;
 
-
   /** @endcond doxygenLibsbmlInternal */
 
 
@@ -225,20 +230,21 @@ public:
    */
   virtual bool accept (SBMLVisitor& v) const;
 
-
   /** @endcond doxygenLibsbmlInternal */
 
 
   /**
   * Parses a gene association in infix format and returns a corresponding
-  * Association object. It also creates all geneProducts, in case the unique
-  * reference does not yet exist. 
+  * Association object.
   *
   * This parses a string that has a list of gene names and conjunctions
   * or disjunctions.  For example:
   * @verbatim
   (b2422) and (b2425) and (b2423) and (b2424) or (b2422) and (b2423) and (b2424) and (b2413) and (b3917)
-  @endverbatim
+@endverbatim
+  *
+  * This method also creates missing GeneProduct objects, in case the unique
+  * reference does not yet exist.
   *
   * @param association the string to parse.
   * @param plugin the FbcModelPlugin on which to add the geneProduct elements
@@ -247,7 +253,8 @@ public:
   *
   * @copydetails doc_note_static_methods
   */
-  static FbcAssociation* parseFbcInfixAssociation(const std::string& association, FbcModelPlugin* plugin);
+  static FbcAssociation* parseFbcInfixAssociation(const std::string& association,
+                                                  FbcModelPlugin* plugin);
 
 
   /**
@@ -265,7 +272,6 @@ public:
    */
   virtual void setSBMLDocument (SBMLDocument* d);
 
-
   /** @endcond doxygenLibsbmlInternal */
 
 
@@ -277,7 +283,6 @@ public:
   virtual void enablePackageInternal(const std::string& pkgURI,
                const std::string& pkgPrefix, bool flag);
 
-
   /** @endcond doxygenLibsbmlInternal */
 
 
@@ -293,7 +298,6 @@ protected:
    */
   virtual void addExpectedAttributes(ExpectedAttributes& attributes);
 
-
   /** @endcond doxygenLibsbmlInternal */
 
 
@@ -305,7 +309,6 @@ protected:
   virtual void readAttributes (const XMLAttributes& attributes,
                                const ExpectedAttributes& expectedAttributes);
 
-
   /** @endcond doxygenLibsbmlInternal */
 
 
@@ -316,26 +319,62 @@ protected:
    */
   virtual void writeAttributes (XMLOutputStream& stream) const;
 
-
   /** @endcond doxygenLibsbmlInternal */
 
 
 
 };
 
+/**
+ * @class ListOfFbcAssociations
+ * @sbmlbrief{fbc} A list of FbcAssociation objects.
+ *
+ * @htmlinclude not-sbml-warning.html
+ *
+ * The ListOfFbcAssociations is a container of FbcAssociation objects for the
+ * FbcAnd and FbcOr classes.  Unlike the ListOf___ classes in SBML, the
+ * ListOfFbcAssociations is not a class that appears in the &ldquo;fbc&rdquo;
+ * Version&nbsp;2 specification, and instead is used internally in libSBML as
+ * a convenience class to store arbitrary numbers of FbcAssociation objects.
+ * Also unlike other ListOf___ classes, the FbcAnd and FbcOr classes require
+ * at least two child FbcAssociation objects, so valid ListOfFbcAssociations
+ * libsbml objects will always contain two or more children.  These children
+ * will have element names associated with their derived class, not the base
+ * FbcAssociation class: <code>&lt;fbc:and&gt;</code>,
+ * <code>&lt;fbc:or&gt;</code>, and <code>&lt;fbc:geneProductRef&gt;</code>.
+ *
+ * @copydetails doc_note_fbcv2_annotation_replacement
+ *
+ * @warning It is important to be clear that <em>ListOfFbcAssociations is not
+ * written out in the XML output produced by libSBML</em>&mdash;the
+ * constructs only exist in software to enable software applications to
+ * manipulate FbcAssociation objects in a way that mirrors how other lists of
+ * components in SBML are manipulated.  ListOfFbcAssociations is abstracted
+ * away when an SBML &ldquo;fbc&rdquo; model file is actually written out in
+ * the final XML form.
+ *
+ * @see FbcAssociation
+ * @see FbcAnd
+ * @see FbcOr
+ * @see GeneProductRef
+ */
 class LIBSBML_EXTERN ListOfFbcAssociations : public ListOf
 {
 
 public:
 
   /**
-   * Creates a new ListOfFbcAssociations with the given level, version, and package version.
+   * Creates a new ListOfFbcAssociations with the given SBML Level, Version,
+   * and &ldquo;fbc&rdquo;package version.
    *
-   * @param level an unsigned int, the SBML Level to assign to this ListOfFbcAssociations
+   * @param level an unsigned int, the SBML Level to assign to this
+   * ListOfFbcAssociations
    *
-   * @param version an unsigned int, the SBML Version to assign to this ListOfFbcAssociations
+   * @param version an unsigned int, the SBML Version to assign to this
+   * ListOfFbcAssociations
    *
-   * @param pkgVersion an unsigned int, the SBML Fbc Version to assign to this ListOfFbcAssociations
+   * @param pkgVersion an unsigned int, the SBML &ldquo;fbc&rdquo; package
+   * Version to assign to this ListOfFbcAssociations
    */
   ListOfFbcAssociations(unsigned int level      = FbcExtension::getDefaultLevel(),
                         unsigned int version    = FbcExtension::getDefaultVersion(),
@@ -343,7 +382,8 @@ public:
 
 
   /**
-   * Creates a new ListOfFbcAssociations with the given FbcPkgNamespaces object.
+   * Creates a new ListOfFbcAssociations with the given FbcPkgNamespaces
+   * object.
    *
    * @param fbcns the FbcPkgNamespaces object
    */
@@ -366,6 +406,7 @@ public:
    * @return the nth FbcAssociation in this ListOfFbcAssociations.
    *
    * @see size()
+   * @see getNumFbcAssociations()
    */
   virtual FbcAssociation* get(unsigned int n);
 
@@ -378,46 +419,46 @@ public:
    * @return the nth FbcAssociation in this ListOfFbcAssociations.
    *
    * @see size()
+   * @see getNumFbcAssociations()
    */
   virtual const FbcAssociation* get(unsigned int n) const;
 
 
   /**
-   * Get a FbcAssociation from the ListOfFbcAssociations
-   * based on its identifier.
+   * Get a FbcAssociation from the ListOfFbcAssociations based on its
+   * identifier.
    *
-   * @param sid a string representing the identifier
-   * of the FbcAssociation to get.
+   * @param sid a string representing the identifier of the FbcAssociation to
+   * get.
    *
-   * @return FbcAssociation in this ListOfFbcAssociations
-   * with the given id or NULL if no such
-   * FbcAssociation exists.
+   * @return FbcAssociation in this ListOfFbcAssociations with the given id
+   * or NULL if no such FbcAssociation exists.
    *
-   * @see get(unsigned int n)   *
+   * @see get(unsigned int n)
    * @see size()
    */
   virtual FbcAssociation* get(const std::string& sid);
 
 
   /**
-   * Get a FbcAssociation from the ListOfFbcAssociations
-   * based on its identifier.
+   * Get a FbcAssociation from the ListOfFbcAssociations based on its
+   * identifier.
    *
-   * @param sid a string representing the identifier
-   * of the FbcAssociation to get.
+   * @param sid a string representing the identifier of the FbcAssociation to
+   * get.
    *
-   * @return FbcAssociation in this ListOfFbcAssociations
-   * with the given id or NULL if no such
-   * FbcAssociation exists.
+   * @return FbcAssociation in this ListOfFbcAssociations with the given id
+   * or NULL if no such FbcAssociation exists.
    *
-   * @see get(unsigned int n)   *
+   * @see get(unsigned int n)
    * @see size()
    */
   virtual const FbcAssociation* get(const std::string& sid) const;
 
 
   /**
-   * Adds a copy the given "FbcAssociation" to this ListOfFbcAssociations.
+   * Adds a copy the given FbcAssociation object to this
+   * ListOfFbcAssociations.
    *
    * @param fa; the FbcAssociation object to add
    *
@@ -425,8 +466,8 @@ public:
    * function.  @if clike The value is drawn from the
    * enumeration #OperationReturnValues_t. @endif The possible values
    * returned by this function are:
-   * @li LIBSEDML_OPERATION_SUCCESS
-   * @li LIBSEDML_INVALID_ATTRIBUTE_VALUE
+   * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
+   * @li @sbmlconstant{LIBSBML_INVALID_ATTRIBUTE_VALUE, OperationReturnValues_t}
    */
   int addFbcAssociation(const FbcAssociation* fa);
 
@@ -434,49 +475,65 @@ public:
   /**
    * Get the number of FbcAssociation objects in this ListOfFbcAssociations.
    *
-   * @return the number of FbcAssociation objects in this ListOfFbcAssociations
+   * @return the number of FbcAssociation objects in this
+   * ListOfFbcAssociations
    */
   unsigned int getNumFbcAssociations() const;
 
 
   /**
-   * Creates a new FbcAssociation object, adds it to the
-   * ListOfFbcAssociations and returns the FbcAssociation object created. 
+   * Creates a new FbcAnd object.
+   *
+   * This method creates a new FbcAssociation object of subclass FbcAnd, adds
+   * it to the ListOfFbcAssociations, and returns the FbcAssociation object
+   * created.
    *
    * @return a new FbcAssociation object instance
    *
+   * @see createOr()
+   * @see createGeneProductRef()
    * @see addFbcAssociation(const FbcAssociation* fa)
    */
   FbcAnd* createAnd();
 
 
   /**
-   * Creates a new FbcAssociation object, adds it to the
-   * ListOfFbcAssociations and returns the FbcAssociation object created. 
+   * Creates a new FbcOr object.
+   *
+   * This method creates a new FbcAssociation object of subclass FbcOr, adds
+   * it to the ListOfFbcAssociations, and returns the FbcAssociation object
+   * created.
    *
    * @return a new FbcAssociation object instance
    *
+   * @see createAnd()
+   * @see createGeneProductRef()
    * @see addFbcAssociation(const FbcAssociation* fa)
    */
   FbcOr* createOr();
 
 
   /**
-   * Creates a new FbcAssociation object, adds it to the
-   * ListOfFbcAssociations and returns the FbcAssociation object created. 
+   * Creates a new GeneProductRef object.
+   *
+   * This method creates a new FbcAssociation object of subclass
+   * GeneProductRef, adds it to the ListOfFbcAssociations, and returns the
+   * FbcAssociation object created.
    *
    * @return a new FbcAssociation object instance
    *
+   * @see createOr()
+   * @see createAnd()
    * @see addFbcAssociation(const FbcAssociation* fa)
    */
   GeneProductRef* createGeneProductRef();
 
 
   /**
-   * Removes the nth FbcAssociation from this ListOfFbcAssociations
-   * and returns a pointer to it.
+   * Removes the nth FbcAssociation
    *
-   * The caller owns the returned item and is responsible for deleting it.
+   * This method removes the nth object from this ListOfFbcAssociations and
+   * returns a pointer to it.
    *
    * @param n the index of the FbcAssociation to remove.
    *
@@ -486,93 +543,58 @@ public:
 
 
   /**
-   * Removes the FbcAssociation from this ListOfFbcAssociations with the given identifier
-   * and returns a pointer to it.
+   * Removes the FbcAssociation with the given identifier
    *
-   * The caller owns the returned item and is responsible for deleting it.
-   * If none of the items in this list have the identifier @p sid, then
-   * @c NULL is returned.
+   * This method searches for and removes the FbcAssociation object with the
+   * given identifier @p sid, and returns a pointer to it.  The caller owns
+   * the returned item and is responsible for deleting it.  If none of the
+   * items in this list have the identifier @p sid, then @c NULL is returned.
    *
    * @param sid the identifier of the FbcAssociation to remove.
    *
-   * @return the FbcAssociation removed. As mentioned above, the caller owns the
-   * returned item.
+   * @return the FbcAssociation removed. As mentioned above, the caller owns
+   * the returned item.
    */
   virtual FbcAssociation* remove(const std::string& sid);
 
 
   /**
-   * Returns the XML element name of this object, which for ListOfFbcAssociations, is
-   * always @c "listOfFbcAssociations".
+   * Returns the XML element name of this object.
    *
-   * @return the name of this element, i.e. @c "listOfFbcAssociations".
+   * For ListOfFbcAssociations, the XML element name is always
+   * @c "listOfFbcAssociations".
+   *
+   * @return the name of this element.
    */
   virtual const std::string& getElementName () const;
 
 
   /**
    * Returns the libSBML type code for this SBML object.
-   * 
-   * @if clike LibSBML attaches an identifying code to every kind of SBML
-   * object.  These are known as <em>SBML type codes</em>.  The set of
-   * possible type codes is defined in the enumeration #SBMLTypeCode_t.
-   * The names of the type codes all begin with the characters @c
-   * SBML_. @endif@if java LibSBML attaches an identifying code to every
-   * kind of SBML object.  These are known as <em>SBML type codes</em>.  In
-   * other languages, the set of type codes is stored in an enumeration; in
-   * the Java language interface for libSBML, the type codes are defined as
-   * static integer constants in the interface class {@link
-   * libsbmlConstants}.  The names of the type codes all begin with the
-   * characters @c SBML_. @endif@if python LibSBML attaches an identifying
-   * code to every kind of SBML object.  These are known as <em>SBML type
-   * codes</em>.  In the Python language interface for libSBML, the type
-   * codes are defined as static integer constants in the interface class
-   * @link libsbml@endlink.  The names of the type codes all begin with the
-   * characters @c SBML_. @endif@if csharp LibSBML attaches an identifying
-   * code to every kind of SBML object.  These are known as <em>SBML type
-   * codes</em>.  In the C# language interface for libSBML, the type codes
-   * are defined as static integer constants in the interface class @link
-   * libsbmlcs.libsbml@endlink.  The names of the type codes all begin with
-   * the characters @c SBML_. @endif
    *
-   * @return the SBML type code for this object, or
-   * @link SBMLTypeCode_t#SBML_UNKNOWN SBML_UNKNOWN@endlink (default).
+   * @copydetails doc_what_are_typecodes
+   *
+   * @return the SBML type code for this object:
+   * @sbmlconstant{SBML_LIST_OF, SBMLTypeCode_t} (default).
+   *
+   * @copydetails doc_warning_typecodes_not_unique
    *
    * @see getElementName()
+   * @see getPackageName()
    */
   virtual int getTypeCode () const;
 
 
   /**
-   * Returns the libSBML type code for the SBML objects
-   * contained in this ListOf object
-   * 
-   * @if clike LibSBML attaches an identifying code to every kind of SBML
-   * object.  These are known as <em>SBML type codes</em>.  The set of
-   * possible type codes is defined in the enumeration #SBMLTypeCode_t.
-   * The names of the type codes all begin with the characters @c
-   * SBML_. @endif@if java LibSBML attaches an identifying code to every
-   * kind of SBML object.  These are known as <em>SBML type codes</em>.  In
-   * other languages, the set of type codes is stored in an enumeration; in
-   * the Java language interface for libSBML, the type codes are defined as
-   * static integer constants in the interface class {@link
-   * libsbmlConstants}.  The names of the type codes all begin with the
-   * characters @c SBML_. @endif@if python LibSBML attaches an identifying
-   * code to every kind of SBML object.  These are known as <em>SBML type
-   * codes</em>.  In the Python language interface for libSBML, the type
-   * codes are defined as static integer constants in the interface class
-   * @link libsbml@endlink.  The names of the type codes all begin with the
-   * characters @c SBML_. @endif@if csharp LibSBML attaches an identifying
-   * code to every kind of SBML object.  These are known as <em>SBML type
-   * codes</em>.  In the C# language interface for libSBML, the type codes
-   * are defined as static integer constants in the interface class @link
-   * libsbmlcs.libsbml@endlink.  The names of the type codes all begin with
-   * the characters @c SBML_. @endif
+   * Returns the libSBML type code for the objects contained in this ListOf.
    *
-   * @return the SBML type code for the objects in this ListOf instance, or
-   * @link SBMLTypeCode_t#SBML_UNKNOWN SBML_UNKNOWN@endlink (default).
+   * @copydetails doc_what_are_typecodes
+   *
+   * @return the SBML type code for the objects contained in this ListOf
+   * instance: @sbmlconstant{SBML_FBC_ASSOCIATION, SBMLTypeCode_t} (default).
    *
    * @see getElementName()
+   * @see getPackageName()
    */
   virtual int getItemTypeCode () const;
 
@@ -586,25 +608,20 @@ protected:
    */
   virtual SBase* createObject(XMLInputStream& stream);
 
-
   /** @endcond doxygenLibsbmlInternal */
 
 
   /** @cond doxygenLibsbmlInternal */
 
   /**
-   * Write the namespace for the Fbc package.
+   * Write the namespace for the &ldquo;fbc&rdquo; package.
    */
   virtual void writeXMLNS(XMLOutputStream& stream) const;
 
-
   /** @endcond doxygenLibsbmlInternal */
 
 
-  virtual bool isValidTypeForList(SBase * item) {
-    int code = item->getTypeCode();
-    return code == getItemTypeCode() || code == SBML_FBC_AND || code == SBML_FBC_OR || code == SBML_FBC_GENEPRODUCTREF ;
-  }
+  virtual bool isValidTypeForList(SBase * item);
 
 
   friend class FbcAnd;
