@@ -7,7 +7,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  * 
- * Copyright (C) 2013-2015 jointly by the following organizations:
+ * Copyright (C) 2013-2016 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -1218,7 +1218,7 @@ static const packageErrorTableEntryV2 fbcErrorTableV2[] =
   },
 
   // 2021201
-  { FbcGeneProcuctAllowedCoreAttributes,
+  { FbcGeneProductAllowedCoreAttributes,
     "Allowed core attributes on <GeneProduct>",
     LIBSBML_CAT_GENERAL_CONSISTENCY,
     LIBSBML_SEV_NOT_APPLICABLE,
@@ -1233,7 +1233,7 @@ static const packageErrorTableEntryV2 fbcErrorTableV2[] =
   },
 
   // 2021202
-  { FbcGeneProcuctAllowedCoreElements,
+  { FbcGeneProductAllowedCoreElements,
     "Allowed core elements on <GeneProduct>",
     LIBSBML_CAT_GENERAL_CONSISTENCY,
     LIBSBML_SEV_NOT_APPLICABLE,
