@@ -7,7 +7,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2015 jointly by the following organizations:
+ * Copyright (C) 2013-2016 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -47,7 +47,6 @@
 
 #include <sbml/packages/multi/sbml/BindingSiteSpeciesType.h>
 #include <sbml/packages/multi/sbml/CompartmentReference.h>
-#include <sbml/packages/multi/sbml/DenotedSpeciesTypeComponentIndex.h>
 #include <sbml/packages/multi/sbml/InSpeciesTypeBond.h>
 #include <sbml/packages/multi/sbml/IntraSpeciesReaction.h>
 #include <sbml/packages/multi/sbml/MultiSpeciesType.h>
@@ -61,8 +60,5 @@
 #include <sbml/packages/multi/sbml/SpeciesTypeComponentMapInProduct.h>
 #include <sbml/packages/multi/sbml/SpeciesTypeInstance.h>
 
-//#include <sbml/packages/multi/validator/MultiSBMLError.h>
-//#include <sbml/packages/multi/validator/MultiValidator.h>
-
 #endif  /* MultiExtensionTypes_H */
 
