@@ -280,7 +280,7 @@ MultiASTPlugin::addExpectedAttributes(ExpectedAttributes& attributes,
 bool 
 MultiASTPlugin::readAttributes(const XMLAttributes& attributes,
                        const ExpectedAttributes& expectedAttributes,
-                               XMLInputStream& stream, XMLToken element,
+                               XMLInputStream& stream, const XMLToken& element,
                                int type)
 {
   bool read = true;
@@ -392,6 +392,15 @@ MultiASTPlugin::writeXMLNS(XMLOutputStream& stream) const
 }
 
 
+void 
+MultiASTPlugin::renameSIdRefs(const std::string& oldid, const std::string& newid)
+{
+  if (!mSpeciesReference.empty() && mSpeciesReference == oldid) {
+    mSpeciesReference = newid;
+  }
+}
+
+
 bool
 MultiASTPlugin::hasAttributesSet() const
 {
@@ -420,7 +429,7 @@ MultiASTPlugin::hasAttributesSet() const
       if (ast != NULL)
       {
         MultiASTPlugin* mp = 
-                        static_cast<MultiASTPlugin*>(ast->getPlugin("multi"));
+                        dynamic_cast<MultiASTPlugin*>(ast->getPlugin("multi"));
         if (mp != NULL)
         {
           hasAttributes = mp->hasAttributesSet();
