@@ -64,11 +64,8 @@ MultiSpeciesPlugin::MultiSpeciesPlugin(const MultiSpeciesPlugin& orig) :
     SBasePlugin(orig)
   , mOutwardBindingSites ( orig.mOutwardBindingSites)
   , mSpeciesFeatures ( orig.mSpeciesFeatures)
+  , mSpeciesType  ( orig.mSpeciesType)
 {
-  if (&orig == NULL)
-  {
-    mSpeciesType  = orig.mSpeciesType;
-  }
 }
 
 
@@ -226,8 +223,9 @@ MultiSpeciesPlugin::readAttributes (const XMLAttributes& attributes,
         const std::string details =
                           getErrorLog()->getError(n)->getMessage();
         getErrorLog()->remove(UnknownPackageAttribute);
-        getErrorLog()->logPackageError("multi", MultiUnknownError,
-                       getPackageVersion(), sbmlLevel, sbmlVersion, details);
+        getErrorLog()->logPackageError("multi", MultiExSpe_AllowedMultiAtts,
+                       getPackageVersion(), sbmlLevel, sbmlVersion, details,
+                       getLine(), getColumn());
       }
       else if (getErrorLog()->getError(n)->getErrorId() == UnknownCoreAttribute)
       {
@@ -235,7 +233,8 @@ MultiSpeciesPlugin::readAttributes (const XMLAttributes& attributes,
                           getErrorLog()->getError(n)->getMessage();
         getErrorLog()->remove(UnknownCoreAttribute);
         getErrorLog()->logPackageError("multi", MultiUnknownError,
-                       getPackageVersion(), sbmlLevel, sbmlVersion, details);
+                       getPackageVersion(), sbmlLevel, sbmlVersion, details,
+                       getLine(), getColumn());
       }
     }
   }
@@ -258,8 +257,10 @@ MultiSpeciesPlugin::readAttributes (const XMLAttributes& attributes,
     }
     else if (SyntaxChecker::isValidSBMLSId(mSpeciesType) == false && getErrorLog() != NULL)
     {
-      getErrorLog()->logError(InvalidIdSyntax, getLevel(), getVersion(), 
-        "The syntax of the attribute speciesType='" + mSpeciesType + "' does not conform.");
+        std::string details = "The syntax of the attribute speciesType='" + mSpeciesType + "' does not conform.";
+        getErrorLog()->logPackageError("multi", MultiInvSIdSyn,
+                   getPackageVersion(), sbmlLevel, sbmlVersion, details,
+                   getLine(), getColumn());
     }
   }
 
@@ -319,11 +320,7 @@ MultiSpeciesPlugin::isSetSpeciesType() const
 int
 MultiSpeciesPlugin::setSpeciesType(const std::string& speciesType)
 {
-  if (&(speciesType) == NULL)
-  {
-    return LIBSBML_INVALID_ATTRIBUTE_VALUE;
-  }
-  else if (!(SyntaxChecker::isValidInternalSId(speciesType)))
+  if (!(SyntaxChecker::isValidInternalSId(speciesType)))
   {
     return LIBSBML_INVALID_ATTRIBUTE_VALUE;
   }
@@ -665,8 +662,6 @@ MultiSpeciesPlugin::createSubListOfSpeciesFeatures ()
   if (losf != NULL)
   {
     mSpeciesFeatures.addSubListOfSpeciesFeatures(losf);
-    //static_cast<ListOfSpeciesFeatures*>(losf)->setIsSubList();
-    //mSpeciesFeaturesmSubListOfSpeciesFeatures->add(losf);
   }
 
   return losf;
@@ -750,10 +745,8 @@ MultiSpeciesPlugin::enablePackageInternal(const std::string& pkgURI,
 bool
 MultiSpeciesPlugin::accept(SBMLVisitor& v) const
 {
-  const Model * model = static_cast<const Model * >(this->getParentSBMLObject());
-
-  v.visit(*model);
-  v.leave(*model);
+  const Species * species = static_cast<const Species * >(this->getParentSBMLObject());
+  v.visit(*species);
 
   for(unsigned int i = 0; i < getNumOutwardBindingSites(); i++)
   {
