@@ -516,6 +516,7 @@ SpeciesFeature::createSpeciesFeatureValue()
 void
 SpeciesFeature::renameSIdRefs(const std::string& oldid, const std::string& newid)
 {
+  SBase::renameSIdRefs(oldid, newid);
   if (isSetSpeciesFeatureType() == true && mSpeciesFeatureType == oldid)
   {
     setSpeciesFeatureType(newid);
@@ -860,7 +861,7 @@ SpeciesFeature::readAttributes (const XMLAttributes& attributes,
   else
   {
     std::string message = "Multi attribute 'speciesFeatureType' is missing.";
-    getErrorLog()->logPackageError("multi", MultiUnknownError,
+    getErrorLog()->logPackageError("multi", MultiSpeFtr_AllowedMultiAtts,
                    getPackageVersion(), sbmlLevel, sbmlVersion, message);
   }
 
@@ -884,7 +885,7 @@ SpeciesFeature::readAttributes (const XMLAttributes& attributes,
       else
       {
         std::string message = "Multi attribute 'occur' is missing.";
-        getErrorLog()->logPackageError("multi", MultiUnknownError,
+        getErrorLog()->logPackageError("multi", MultiSpeFtr_AllowedMultiAtts,
                        getPackageVersion(), sbmlLevel, sbmlVersion, message);
       }
     }
