@@ -45,16 +45,10 @@ SpeciesTypeComponentIndex::SpeciesTypeComponentIndex (unsigned int level, unsign
   : SBase(level, version)
    ,mId ("")
    ,mComponent ("")
-   ,mOccur (SBML_INT_MAX)
-   ,mIsSetOccur (false)
    ,mIdentifyingParent ("")
-   ,mDenotedSpeciesTypeComponentIndexes (level, version, pkgVersion)
 {
   // set an SBMLNamespaces derived object of this package
   setSBMLNamespacesAndOwn(new MultiPkgNamespaces(level, version, pkgVersion));
-
-  // connect to child objects
-  connectToChild();
 }
 
 
@@ -65,17 +59,11 @@ SpeciesTypeComponentIndex::SpeciesTypeComponentIndex (MultiPkgNamespaces* multin
   : SBase(multins)
    ,mId ("")
    ,mComponent ("")
-   ,mOccur (SBML_INT_MAX)
-   ,mIsSetOccur (false)
    ,mIdentifyingParent ("")
-   ,mDenotedSpeciesTypeComponentIndexes (multins)
 {
   // set the element namespace of this object
   setElementNamespace(multins->getURI());
 
-  // connect to child objects
-  connectToChild();
-
   // load package extensions bound with this object (if any) 
   loadPlugins(multins);
 }
@@ -88,13 +76,8 @@ SpeciesTypeComponentIndex::SpeciesTypeComponentIndex (const SpeciesTypeComponent
   : SBase(orig)
   , mId  ( orig.mId)
   , mComponent  ( orig.mComponent)
-  , mOccur  ( orig.mOccur)
-  , mIsSetOccur  ( orig.mIsSetOccur)
   , mIdentifyingParent  ( orig.mIdentifyingParent)
-  , mDenotedSpeciesTypeComponentIndexes  ( orig.mDenotedSpeciesTypeComponentIndexes)
 {
-  // connect to child objects
-  connectToChild();
 }
 
 
@@ -109,13 +92,7 @@ SpeciesTypeComponentIndex::operator=(const SpeciesTypeComponentIndex& rhs)
     SBase::operator=(rhs);
     mId  = rhs.mId;
     mComponent  = rhs.mComponent;
-    mOccur  = rhs.mOccur;
-    mIsSetOccur  = rhs.mIsSetOccur;
     mIdentifyingParent  = rhs.mIdentifyingParent;
-    mDenotedSpeciesTypeComponentIndexes  = rhs.mDenotedSpeciesTypeComponentIndexes;
-
-    // connect to child objects
-    connectToChild();
   }
   return *this;
 }
@@ -159,16 +136,6 @@ SpeciesTypeComponentIndex::getComponent() const
 }
 
 
-/*
- * Returns the value of the "occur" attribute of this SpeciesTypeComponentIndex.
- */
-unsigned int
-SpeciesTypeComponentIndex::getOccur() const
-{
-  return mOccur;
-}
-
-
 /*
  * Returns the value of the "identifyingParent" attribute of this SpeciesTypeComponentIndex.
  */
@@ -199,16 +166,6 @@ SpeciesTypeComponentIndex::isSetComponent() const
 }
 
 
-/*
- * Returns true/false if occur is set.
- */
-bool
-SpeciesTypeComponentIndex::isSetOccur() const
-{
-  return mIsSetOccur;
-}
-
-
 /*
  * Returns true/false if identifyingParent is set.
  */
@@ -247,18 +204,6 @@ SpeciesTypeComponentIndex::setComponent(const std::string& component)
 }
 
 
-/*
- * Sets occur and returns value indicating success.
- */
-int
-SpeciesTypeComponentIndex::setOccur(unsigned int occur)
-{
-  mOccur = occur;
-  mIsSetOccur = true;
-  return LIBSBML_OPERATION_SUCCESS;
-}
-
-
 /*
  * Sets identifyingParent and returns value indicating success.
  */
@@ -315,26 +260,6 @@ SpeciesTypeComponentIndex::unsetComponent()
 }
 
 
-/*
- * Unsets occur and returns value indicating success.
- */
-int
-SpeciesTypeComponentIndex::unsetOccur()
-{
-  mOccur = SBML_INT_MAX;
-  mIsSetOccur = false;
-
-  if (isSetOccur() == false)
-  {
-    return LIBSBML_OPERATION_SUCCESS;
-  }
-  else
-  {
-    return LIBSBML_OPERATION_FAILED;
-  }
-}
-
-
 /*
  * Unsets identifyingParent and returns value indicating success.
  */
@@ -354,169 +279,13 @@ SpeciesTypeComponentIndex::unsetIdentifyingParent()
 }
 
 
-/*
- * Returns the  "ListOfDenotedSpeciesTypeComponentIndexes" in this SpeciesTypeComponentIndex object.
- */
-const ListOfDenotedSpeciesTypeComponentIndexes*
-SpeciesTypeComponentIndex::getListOfDenotedSpeciesTypeComponentIndexes() const
-{
-  return &mDenotedSpeciesTypeComponentIndexes;
-}
-
-
-/*
- * Returns the  "ListOfDenotedSpeciesTypeComponentIndexes" in this SpeciesTypeComponentIndex object.
- */
-ListOfDenotedSpeciesTypeComponentIndexes*
-SpeciesTypeComponentIndex::getListOfDenotedSpeciesTypeComponentIndexes()
-{
-  return &mDenotedSpeciesTypeComponentIndexes;
-}
-
-
-/*
- * Removes the nth DenotedSpeciesTypeComponentIndex from the ListOfDenotedSpeciesTypeComponentIndexes.
- */
-DenotedSpeciesTypeComponentIndex*
-SpeciesTypeComponentIndex::removeDenotedSpeciesTypeComponentIndex(unsigned int n)
-{
-  return mDenotedSpeciesTypeComponentIndexes.remove(n);
-}
-
-
-/*
- * Removes the a DenotedSpeciesTypeComponentIndex with given id from the ListOfDenotedSpeciesTypeComponentIndexes.
- */
-DenotedSpeciesTypeComponentIndex*
-SpeciesTypeComponentIndex::removeDenotedSpeciesTypeComponentIndex(const std::string& sid)
-{
-  return mDenotedSpeciesTypeComponentIndexes.remove(sid);
-}
-
-
-/*
- * Return the nth DenotedSpeciesTypeComponentIndex in the ListOfDenotedSpeciesTypeComponentIndexes within this SpeciesTypeComponentIndex.
- */
-DenotedSpeciesTypeComponentIndex*
-SpeciesTypeComponentIndex::getDenotedSpeciesTypeComponentIndex(unsigned int n)
-{
-  return mDenotedSpeciesTypeComponentIndexes.get(n);
-}
-
-
-/*
- * Return the nth DenotedSpeciesTypeComponentIndex in the ListOfDenotedSpeciesTypeComponentIndexes within this SpeciesTypeComponentIndex.
- */
-const DenotedSpeciesTypeComponentIndex*
-SpeciesTypeComponentIndex::getDenotedSpeciesTypeComponentIndex(unsigned int n) const
-{
-  return mDenotedSpeciesTypeComponentIndexes.get(n);
-}
-
-
-/*
- * Return a DenotedSpeciesTypeComponentIndex from the ListOfDenotedSpeciesTypeComponentIndexes by id.
- */
-DenotedSpeciesTypeComponentIndex*
-SpeciesTypeComponentIndex::getDenotedSpeciesTypeComponentIndex(const std::string& sid)
-{
-  return mDenotedSpeciesTypeComponentIndexes.get(sid);
-}
-
-
-/*
- * Return a DenotedSpeciesTypeComponentIndex from the ListOfDenotedSpeciesTypeComponentIndexes by id.
- */
-const DenotedSpeciesTypeComponentIndex*
-SpeciesTypeComponentIndex::getDenotedSpeciesTypeComponentIndex(const std::string& sid) const
-{
-  return mDenotedSpeciesTypeComponentIndexes.get(sid);
-}
-
-
-/*
- * Adds a copy the given "DenotedSpeciesTypeComponentIndex" to this SpeciesTypeComponentIndex.
- */
-int
-SpeciesTypeComponentIndex::addDenotedSpeciesTypeComponentIndex(const DenotedSpeciesTypeComponentIndex* dstci)
-{
-  if (dstci == NULL)
-  {
-    return LIBSBML_OPERATION_FAILED;
-  }
-  else if (dstci->hasRequiredAttributes() == false)
-  {
-    return LIBSBML_INVALID_OBJECT;
-  }
-  else if (getLevel() != dstci->getLevel())
-  {
-    return LIBSBML_LEVEL_MISMATCH;
-  }
-  else if (getVersion() != dstci->getVersion())
-  {
-    return LIBSBML_VERSION_MISMATCH;
-  }
-  else if (matchesRequiredSBMLNamespacesForAddition(static_cast<const SBase *>(dstci)) == false)
-  {
-    return LIBSBML_NAMESPACES_MISMATCH;
-  }
-  else
-  {
-    mDenotedSpeciesTypeComponentIndexes.append(dstci);
-
-    return LIBSBML_OPERATION_SUCCESS;
-  }
-}
-
-
-/*
- * Get the number of DenotedSpeciesTypeComponentIndex objects in this SpeciesTypeComponentIndex.
- */
-unsigned int
-SpeciesTypeComponentIndex::getNumDenotedSpeciesTypeComponentIndexes() const
-{
-  return mDenotedSpeciesTypeComponentIndexes.size();
-}
-
-
-/*
- * Creates a new DenotedSpeciesTypeComponentIndex object, adds it to this SpeciesTypeComponentIndexes
- */
-DenotedSpeciesTypeComponentIndex*
-SpeciesTypeComponentIndex::createDenotedSpeciesTypeComponentIndex()
-{
-  DenotedSpeciesTypeComponentIndex* dstci = NULL;
-
-  try
-  {
-    MULTI_CREATE_NS(multins, getSBMLNamespaces());
-    dstci = new DenotedSpeciesTypeComponentIndex(multins);
-    delete multins;
-  }
-  catch (...)
-  {
-    /* here we do not create a default object as the level/version must
-     * match the parent object
-     *
-     * do nothing
-     */
-  }
-
-  if(dstci != NULL)
-  {
-    mDenotedSpeciesTypeComponentIndexes.appendAndOwn(dstci);
-  }
-
-  return dstci;
-}
-
-
 /*
  * rename attributes that are SIdRefs or instances in math
  */
 void
 SpeciesTypeComponentIndex::renameSIdRefs(const std::string& oldid, const std::string& newid)
 {
+  SBase::renameSIdRefs(oldid, newid);
   if (isSetComponent() == true && mComponent == oldid)
   {
     setComponent(newid);
@@ -530,20 +299,6 @@ SpeciesTypeComponentIndex::renameSIdRefs(const std::string& oldid, const std::st
 }
 
 
-List*
-SpeciesTypeComponentIndex::getAllElements(ElementFilter* filter)
-{
-  List* ret = new List();
-  List* sublist = NULL;
-
-  ADD_FILTERED_LIST(ret, sublist, mDenotedSpeciesTypeComponentIndexes, filter);
-
-  ADD_FILTERED_FROM_PLUGIN(ret, sublist, filter);
-
-  return ret;
-}
-
-
 /*
  * Returns the XML element name of this object
  */
@@ -579,21 +334,6 @@ SpeciesTypeComponentIndex::hasRequiredAttributes () const
   if (isSetComponent() == false)
     allPresent = false;
 
-  if (isSetOccur() == false)
-    allPresent = false;
-
-  return allPresent;
-}
-
-
-/*
- * check if all the required elements are set
- */
-bool
-SpeciesTypeComponentIndex::hasRequiredElements () const
-{
-  bool allPresent = true;
-
   return allPresent;
 }
 
@@ -608,11 +348,6 @@ SpeciesTypeComponentIndex::writeElements (XMLOutputStream& stream) const
 {
   SBase::writeElements(stream);
 
-  if (getNumDenotedSpeciesTypeComponentIndexes() > 0)
-  {
-    mDenotedSpeciesTypeComponentIndexes.write(stream);
-  }
-
   SBase::writeExtensionElements(stream);
 }
 
@@ -630,12 +365,6 @@ SpeciesTypeComponentIndex::accept (SBMLVisitor& v) const
 {
   v.visit(*this);
 
-  // DenotedSpeciesTypeComponentIndex
-  for(unsigned int i = 0; i < getNumDenotedSpeciesTypeComponentIndexes(); i++)
-  {
-    getDenotedSpeciesTypeComponentIndex(i)->accept(v);
-  }
-
   return true;
 }
 
@@ -652,22 +381,6 @@ void
 SpeciesTypeComponentIndex::setSBMLDocument (SBMLDocument* d)
 {
   SBase::setSBMLDocument(d);
-  mDenotedSpeciesTypeComponentIndexes.setSBMLDocument(d);
-}
-
-
-  /** @endcond doxygenLibsbmlInternal */
-
-
-  /** @cond doxygenLibsbmlInternal */
-
-/*
-   * Connects to child elements.
- */
-void
-SpeciesTypeComponentIndex::connectToChild()
-{
-  mDenotedSpeciesTypeComponentIndexes.connectToParent(this);
 }
 
 
@@ -684,7 +397,6 @@ SpeciesTypeComponentIndex::enablePackageInternal(const std::string& pkgURI,
              const std::string& pkgPrefix, bool flag)
 {
   SBase::enablePackageInternal(pkgURI, pkgPrefix, flag);
-  mDenotedSpeciesTypeComponentIndexes.enablePackageInternal(pkgURI, pkgPrefix, flag);
 }
 
 
@@ -704,11 +416,6 @@ SpeciesTypeComponentIndex::createObject(XMLInputStream& stream)
 
   MULTI_CREATE_NS(multins, getSBMLNamespaces());
 
-  if (name == "listOfDenotedSpeciesTypeComponentIndexes")
-  {
-    object = &mDenotedSpeciesTypeComponentIndexes;
-  }
-
   delete multins;
   return object;
 }
@@ -729,7 +436,6 @@ SpeciesTypeComponentIndex::addExpectedAttributes(ExpectedAttributes& attributes)
 
   attributes.add("id");
   attributes.add("component");
-  attributes.add("occur");
   attributes.add("identifyingParent");
 }
 
@@ -841,7 +547,7 @@ SpeciesTypeComponentIndex::readAttributes (const XMLAttributes& attributes,
   else
   {
     std::string message = "Multi attribute 'id' is missing.";
-    getErrorLog()->logPackageError("multi", MultiUnknownError,
+    getErrorLog()->logPackageError("multi", MultiSptCpoInd_AllowedMultiAtts,
                    getPackageVersion(), sbmlLevel, sbmlVersion, message,
                    getLine(), getColumn());
   }
@@ -870,40 +576,11 @@ SpeciesTypeComponentIndex::readAttributes (const XMLAttributes& attributes,
   else
   {
     std::string message = "Multi attribute 'component' is missing.";
-    getErrorLog()->logPackageError("multi", MultiUnknownError,
+    getErrorLog()->logPackageError("multi", MultiSptCpoInd_AllowedMultiAtts,
                    getPackageVersion(), sbmlLevel, sbmlVersion, message,
                    getLine(), getColumn());
   }
 
-  //
-  // occur unsigned int   ( use = "required" )
-  //
-  numErrs = getErrorLog()->getNumErrors();
-  mIsSetOccur = attributes.readInto("occur", mOccur);
-
-  if (mIsSetOccur == false)
-  {
-    if (getErrorLog() != NULL)
-    {
-      if (getErrorLog()->getNumErrors() == numErrs + 1 &&
-              getErrorLog()->contains(XMLAttributeTypeMismatch))
-      {
-        std::string message = getErrorLog()->getError(numErrs)->getMessage();
-        getErrorLog()->remove(XMLAttributeTypeMismatch);
-        getErrorLog()->logPackageError("multi", MultiSptCpoInd_OccAtt_Ref,
-                     getPackageVersion(), sbmlLevel, sbmlVersion, message,
-                     getLine(), getColumn());
-      }
-      else
-      {
-        std::string message = "Multi attribute 'occur' is missing.";
-        getErrorLog()->logPackageError("multi", MultiUnknownError,
-                       getPackageVersion(), sbmlLevel, sbmlVersion, message,
-                       getLine(), getColumn());
-      }
-    }
-  }
-
   //
   // identifyingParent SIdRef   ( use = "optional" )
   //
@@ -948,9 +625,6 @@ SpeciesTypeComponentIndex::writeAttributes (XMLOutputStream& stream) const
   if (isSetComponent() == true)
     stream.writeAttribute("component", getPrefix(), mComponent);
 
-  if (isSetOccur() == true)
-    stream.writeAttribute("occur", getPrefix(), mOccur);
-
   if (isSetIdentifyingParent() == true)
     stream.writeAttribute("identifyingParent", getPrefix(), mIdentifyingParent);
 
@@ -1224,17 +898,6 @@ SpeciesTypeComponentIndex_getComponent(SpeciesTypeComponentIndex_t * stci)
 }
 
 
-/**
- * 
- */
-LIBSBML_EXTERN
-unsigned int
-SpeciesTypeComponentIndex_getOccur(SpeciesTypeComponentIndex_t * stci)
-{
-  return (stci != NULL) ? stci->getOccur() : SBML_INT_MAX;
-}
-
-
 /**
  * 
  */
@@ -1271,17 +934,6 @@ SpeciesTypeComponentIndex_isSetComponent(SpeciesTypeComponentIndex_t * stci)
 }
 
 
-/**
- * 
- */
-LIBSBML_EXTERN
-int
-SpeciesTypeComponentIndex_isSetOccur(SpeciesTypeComponentIndex_t * stci)
-{
-  return (stci != NULL) ? static_cast<int>(stci->isSetOccur()) : 0;
-}
-
-
 /**
  * 
  */
@@ -1315,17 +967,6 @@ SpeciesTypeComponentIndex_setComponent(SpeciesTypeComponentIndex_t * stci, const
 }
 
 
-/**
- * 
- */
-LIBSBML_EXTERN
-int
-SpeciesTypeComponentIndex_setOccur(SpeciesTypeComponentIndex_t * stci, unsigned int occur)
-{
-  return (stci != NULL) ? stci->setOccur(occur) : LIBSBML_INVALID_OBJECT;
-}
-
-
 /**
  * 
  */
@@ -1359,17 +1000,6 @@ SpeciesTypeComponentIndex_unsetComponent(SpeciesTypeComponentIndex_t * stci)
 }
 
 
-/**
- * 
- */
-LIBSBML_EXTERN
-int
-SpeciesTypeComponentIndex_unsetOccur(SpeciesTypeComponentIndex_t * stci)
-{
-  return (stci != NULL) ? stci->unsetOccur() : LIBSBML_INVALID_OBJECT;
-}
-
-
 /**
  * 
  */
