@@ -32,6 +32,7 @@
 #include <sbml/packages/multi/validator/MultiValidator.h>
 
 #include <sbml/SBMLReader.h>
+#include <sbml/ModifierSpeciesReference.h>
 
 
   /** @cond doxygenLibsbmlInternal */
@@ -135,22 +136,22 @@ protected:
  */
 struct MultiValidatorConstraints
 {
-  ConstraintSet<SBMLDocument>             mSBMLDocument;
-  ConstraintSet<Model>                    mModel;
+  ConstraintSet<SBMLDocument>          mSBMLDocument;
+  ConstraintSet<Model>                 mModel;
   ConstraintSet<PossibleSpeciesFeatureValue>      mPossibleSpeciesFeatureValue;
-  ConstraintSet<SpeciesFeatureValue>      mSpeciesFeatureValue;
-  ConstraintSet<CompartmentReference>      mCompartmentReference;
-  ConstraintSet<SpeciesTypeInstance>      mSpeciesTypeInstance;
-  ConstraintSet<InSpeciesTypeBond>      mInSpeciesTypeBond;
-  ConstraintSet<DenotedSpeciesTypeComponentIndex>      mDenotedSpeciesTypeComponentIndex;
-  ConstraintSet<OutwardBindingSite>      mOutwardBindingSite;
-  ConstraintSet<SpeciesFeatureChange>      mSpeciesFeatureChange;
-  ConstraintSet<SpeciesFeatureType>      mSpeciesFeatureType;
+  ConstraintSet<SpeciesFeatureValue>   mSpeciesFeatureValue;
+  ConstraintSet<CompartmentReference>  mCompartmentReference;
+  ConstraintSet<SpeciesTypeInstance>   mSpeciesTypeInstance;
+  ConstraintSet<InSpeciesTypeBond>     mInSpeciesTypeBond;
+  ConstraintSet<OutwardBindingSite>    mOutwardBindingSite;
+  ConstraintSet<SpeciesFeatureChange>  mSpeciesFeatureChange;
+  ConstraintSet<SpeciesFeatureType>    mSpeciesFeatureType;
   ConstraintSet<SpeciesTypeComponentIndex>      mSpeciesTypeComponentIndex;
-  ConstraintSet<SpeciesFeature>      mSpeciesFeature;
+  ConstraintSet<SpeciesFeature>        mSpeciesFeature;
   ConstraintSet<SpeciesTypeComponentMapInProduct>      mSpeciesTypeComponentMapInProduct;
   ConstraintSet<MultiSpeciesType>      mMultiSpeciesType;
   ConstraintSet<Compartment>           mCompartment;
+  ConstraintSet<Species>           	   mSpecies;
   map<VConstraint*,bool> ptrMap;
 
   ~MultiValidatorConstraints ();
@@ -230,12 +231,6 @@ MultiValidatorConstraints::add (VConstraint* c)
     return;
   }
 
-  if (dynamic_cast< TConstraint<DenotedSpeciesTypeComponentIndex>* >(c) != NULL)
-  {
-    mDenotedSpeciesTypeComponentIndex.add( static_cast< TConstraint<DenotedSpeciesTypeComponentIndex>* >(c) );
-    return;
-  }
-
   if (dynamic_cast< TConstraint<OutwardBindingSite>* >(c) != NULL)
   {
     mOutwardBindingSite.add( static_cast< TConstraint<OutwardBindingSite>* >(c) );
@@ -282,6 +277,11 @@ MultiValidatorConstraints::add (VConstraint* c)
     mCompartment.add( static_cast< TConstraint<Compartment>* >(c) );
     return;
   }
+  if (dynamic_cast< TConstraint<Species>* >(c) != NULL)
+  {
+    mSpecies.add( static_cast< TConstraint<Species>* >(c) );
+    return;
+  }
 
 }
 
@@ -348,12 +348,6 @@ public:
     return !v.mMultiConstraints->mInSpeciesTypeBond.empty();
   }
 
-  bool visit (const DenotedSpeciesTypeComponentIndex &x)
-  {
-    v.mMultiConstraints->mDenotedSpeciesTypeComponentIndex.applyTo(m, x);
-    return !v.mMultiConstraints->mDenotedSpeciesTypeComponentIndex.empty();
-  }
-
   bool visit (const OutwardBindingSite &x)
   {
     v.mMultiConstraints->mOutwardBindingSite.applyTo(m, x);
@@ -401,6 +395,21 @@ public:
     v.mMultiConstraints->mCompartment.applyTo(m, x);
     return !v.mMultiConstraints->mCompartment.empty();
   }
+  bool visit (const Species &x)
+  {
+    v.mMultiConstraints->mSpecies.applyTo(m, x);
+    return !v.mMultiConstraints->mSpecies.empty();
+  }
+//  bool visit (const Reaction &x)
+//  {
+//    v.mMultiConstraints->mReactions.applyTo(m, x);
+//    return !v.mMultiConstraints->mReactions.empty();
+//  }
+//  bool visit (const ASTNode &x)
+//  {
+//    v.mMultiConstraints->mASTNodes.applyTo(m, x);
+//    return !v.mMultiConstraints->mASTNodes.empty();
+//  }
   virtual bool visit(const SBase &x)
   {
     if (x.getPackageName() != "multi")
@@ -438,10 +447,6 @@ public:
       {
         return visit((const InSpeciesTypeBond&)x);
       }
-      else if (code == SBML_MULTI_DENOTED_SPECIES_TYPE_COMPONENT_INDEX)
-      {
-        return visit((const DenotedSpeciesTypeComponentIndex&)x);
-      }
       else if (code == SBML_MULTI_OUTWARD_BINDING_SITE)
       {
         return visit((const OutwardBindingSite&)x);
@@ -466,7 +471,7 @@ public:
       {
         return visit((const SpeciesTypeComponentMapInProduct&)x);
       }
-      else if (code == SBML_MULTI_SPECIES_TYPE)
+      else if (code == SBML_MULTI_SPECIES_TYPE || code == SBML_MULTI_BINDING_SITE_SPECIES_TYPE)
       {
         return visit((const MultiSpeciesType&)x);
       }
@@ -545,13 +550,13 @@ MultiValidator::validate (const SBMLDocument& d)
     ACCEPT_MULTI(m, vv);
 
     // Compartment
-    for (int i = 0; i < m->getNumCompartments(); i++)
+    for (unsigned int i = 0; i < m->getNumCompartments(); i++)
     {
       ACCEPT_MULTI(m->getCompartment(i),vv);
     }
 
     //  Species
-    for (int i = 0; i < m->getNumSpecies(); i++)
+    for (unsigned int i = 0; i < m->getNumSpecies(); i++)
     {
       ACCEPT_MULTI(m->getSpecies(i),vv);
     }
@@ -560,19 +565,19 @@ MultiValidator::validate (const SBMLDocument& d)
     ACCEPT_MULTI(m->getListOfReactions(), vv);
 
     // Reaction
-    for (int i = 0; i < m->getNumReactions(); i++)
+    for (unsigned int i = 0; i < m->getNumReactions(); i++)
     {
       const Reaction * r = m->getReaction(i);
 
-      for (int j = 0; j < r->getNumReactants(); j++)
+      for (unsigned int j = 0; j < r->getNumReactants(); j++)
       {
         ACCEPT_MULTI(r->getReactant(j),vv);
       }
-      for (int j = 0; j < r->getNumProducts(); j++)
+      for (unsigned int j = 0; j < r->getNumProducts(); j++)
       {
         ACCEPT_MULTI(r->getProduct(j),vv);
       }
-      for (int j = 0; j < r->getNumModifiers(); j++)
+      for (unsigned int j = 0; j < r->getNumModifiers(); j++)
       {
         ACCEPT_MULTI(r->getModifier(j),vv);
       }
@@ -581,6 +586,19 @@ MultiValidator::validate (const SBMLDocument& d)
       if (kineticLaw) {
           const ASTNode * math = kineticLaw->getMath();
           // TODO for validation of ci elements
+			const List * listNumberNodes = math->getListOfNodes((ASTNodePredicate)ASTNode_isNumber);
+
+			for (unsigned int i = 0; i < listNumberNodes->getSize(); i++)
+			{
+				const ASTNode * node = static_cast<const ASTNode *> (listNumberNodes->get(i));
+				if (node != NULL) {
+					const MultiASTPlugin * astPlugin = static_cast<const MultiASTPlugin*>(node->getPlugin("multi"));
+					if (astPlugin != NULL) {
+//						astPlugin-
+					}
+				}
+			}
+
       }
     }
 
