@@ -7,7 +7,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2015 jointly by the following organizations:
+ * Copyright (C) 2013-2016 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -89,22 +89,15 @@ CSGRotation::CSGRotation (SpatialPkgNamespaces* spatialns)
  */
 CSGRotation::CSGRotation (const CSGRotation& orig)
   : CSGTransformation(orig)
+  , mRotateX  ( orig.mRotateX)
+  , mIsSetRotateX  ( orig.mIsSetRotateX)
+  , mRotateY  ( orig.mRotateY)
+  , mIsSetRotateY  ( orig.mIsSetRotateY)
+  , mRotateZ  ( orig.mRotateZ)
+  , mIsSetRotateZ  ( orig.mIsSetRotateZ)
+  , mRotateAngleInRadians  ( orig.mRotateAngleInRadians)
+  , mIsSetRotateAngleInRadians  ( orig.mIsSetRotateAngleInRadians)
 {
-  if (&orig == NULL)
-  {
-    throw SBMLConstructorException("Null argument to copy constructor");
-  }
-  else
-  {
-    mRotateX  = orig.mRotateX;
-    mIsSetRotateX  = orig.mIsSetRotateX;
-    mRotateY  = orig.mRotateY;
-    mIsSetRotateY  = orig.mIsSetRotateY;
-    mRotateZ  = orig.mRotateZ;
-    mIsSetRotateZ  = orig.mIsSetRotateZ;
-    mRotateAngleInRadians  = orig.mRotateAngleInRadians;
-    mIsSetRotateAngleInRadians  = orig.mIsSetRotateAngleInRadians;
-  }
 }
 
 
@@ -114,11 +107,7 @@ CSGRotation::CSGRotation (const CSGRotation& orig)
 CSGRotation&
 CSGRotation::operator=(const CSGRotation& rhs)
 {
-  if (&rhs == NULL)
-  {
-    throw SBMLConstructorException("Null argument to assignment");
-  }
-  else if (&rhs != this)
+  if (&rhs != this)
   {
     CSGTransformation::operator=(rhs);
     mRotateX  = rhs.mRotateX;
