@@ -9,7 +9,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2015 jointly by the following organizations:
+ * Copyright (C) 2013-2016 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -125,7 +125,7 @@ PieceBooleanMathCheck::checkMath (const Model& m, const ASTNode& node, const SBa
   * If not, an error message is logged.
   */
 void 
-PieceBooleanMathCheck::checkPiece (const Model& m, const ASTNode& node, 
+PieceBooleanMathCheck::checkPiece (const Model&, const ASTNode& node, 
                                         const SBase & sb)
 {
   unsigned int numChildren = node.getNumChildren();
