@@ -9,7 +9,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2015 jointly by the following organizations:
+ * Copyright (C) 2013-2016 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -603,7 +603,7 @@ START_CONSTRAINT( 9999508, Parameter, p)
   UnitDefinition * ud =  const_cast<UnitDefinition*>(p.getDerivedUnitDefinition());
   
   bool isNotNull = ud != NULL;
-  int numUnits = isNotNull ? ud->getNumUnits() : 0;
+  int numUnits = isNotNull ? (int)ud->getNumUnits() : 0;
   
   if (!isNotNull)  
 
