@@ -9,7 +9,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2015 jointly by the following organizations:
+ * Copyright (C) 2013-2016 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -745,6 +745,11 @@ XMLOutputStream::upIndent ()
   if (mDoIndent) ++mIndent;
 }
 
+bool XMLOutputStream::getStringStream()
+{
+  return mStringStream;
+}
+
 
 /*
  * Outputs indentation whitespace.
@@ -903,6 +908,18 @@ XMLOutputStream::writeValue (const unsigned int& value)
   mStream << '=' << '"' << value << '"';
 }
 
+void
+XMLOutputStream::setStringStream()
+{
+  mStringStream = true;
+}
+
+void
+XMLOutputStream::unsetStringStream()
+{
+  mStringStream = false;
+}
+
 
 /*
  * Writes the XML declaration:
@@ -1076,6 +1093,12 @@ XMLOutputStringStream::XMLOutputStringStream (  std::ostringstream& stream
   setStringStream();
 }
 
+std::ostringstream &
+XMLOutputStringStream::getString()
+{
+  return mString;
+}
+
 XMLOwningOutputStringStream::XMLOwningOutputStringStream (  const std::string&  encoding
                                , bool                writeXMLDecl
                                , const std::string&  programName
