@@ -7,7 +7,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2015 jointly by the following organizations:
+ * Copyright (C) 2013-2016 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -688,7 +688,7 @@ on yyyy-MM-dd HH:mm with libSBML version <libsbml version>. -->
 
 
   /** @cond doxygenLibsbmlInternal */
-  bool getStringStream()   { return mStringStream;  }
+  bool getStringStream();
   /** @endcond */
 
 
@@ -817,8 +817,8 @@ protected:
 
   /* this is needed for the derived classes used to create the C wrapper */
   bool mStringStream;
-  void setStringStream()   { mStringStream = true;  }
-  void unsetStringStream() { mStringStream = false; }
+  void setStringStream();
+  void unsetStringStream();
 
   /** @endcond */
 };
@@ -840,11 +840,12 @@ public:
                          , const std::string&  programName  = ""
                          , const std::string&  programVersion = "");
 
-  std::ostringstream& getString() { return mString; }
+  std::ostringstream& getString();
 
 protected:
-
+  /** @cond doxygenLibsbmlInternal */
   std::ostringstream& mString;
+  /** @endcond */
 };
 /** @endcond */
 
